==> blesta-5.10.2.zip: blesta/plugins/webhooks/language/id_id/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.category_incoming'] = 'Masuk';
$lang['AdminMain.edit.text_fields_map'] = 'Bagian ini memungkinkan Anda mengganti nama bidang peristiwa yang dipicu menjadi nama khusus sebelum dikirim ke panggilan balik. Subbidang harus dipisahkan dengan titik (misalnya vars.status). Untuk melihat daftar semua bidang yang didukung oleh masing-masing peristiwa, Anda dapat memeriksa <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">tautan</a> berikut ini.';
$lang['AdminMain.edit.field_editsubmit'] = 'Edit Webhook';
$lang['AdminMain.edit.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminMain.edit.field_method'] = 'Metode';
$lang['AdminMain.edit.field_type'] = 'Panggilan balik';
$lang['AdminMain.edit.field_event'] = 'Acara';
$lang['AdminMain.edit.field_callback'] = 'Panggilan balik';
$lang['AdminMain.edit.option_delete'] = 'Menghapus';
$lang['AdminMain.edit.heading_options'] = 'Pilihan';
$lang['AdminMain.edit.heading_parameter'] = 'Bidang Baru';
$lang['AdminMain.edit.heading_field'] = 'Bidang Asli';
$lang['AdminMain.edit.heading_fields_map'] = 'Peta Bidang';
$lang['AdminMain.edit.heading_event'] = 'Acara';
$lang['AdminMain.edit.boxtitle_editwebhook'] = 'Edit Webhook';
$lang['AdminMain.add.text_fields_map'] = 'Bagian ini memungkinkan Anda mengganti nama bidang peristiwa yang dipicu menjadi nama khusus sebelum dikirim ke panggilan balik. Subbidang harus dipisahkan dengan titik (misalnya vars.status). Untuk melihat daftar semua bidang yang didukung oleh masing-masing peristiwa, Anda dapat memeriksa <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">tautan</a> berikut ini.';
$lang['AdminMain.add.field_addsubmit'] = 'Tambahkan Webhook';
$lang['AdminMain.add.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminMain.add.field_method'] = 'Metode';
$lang['AdminMain.add.field_type'] = 'Panggilan balik';
$lang['AdminMain.add.field_event'] = 'Acara';
$lang['AdminMain.add.field_callback'] = 'Panggilan balik';
$lang['AdminMain.add.option_delete'] = 'Menghapus';
$lang['AdminMain.add.heading_options'] = 'Pilihan';
$lang['AdminMain.add.heading_parameter'] = 'Bidang Baru';
$lang['AdminMain.add.heading_field'] = 'Bidang Asli';
$lang['AdminMain.add.heading_fields_map'] = 'Peta Bidang';
$lang['AdminMain.add.heading_event'] = 'Acara';
$lang['AdminMain.add.boxtitle_addwebhook'] = 'Tambahkan Webhook';
$lang['AdminMain.index.no_results'] = 'Tidak ada webhook yang tersedia.';
$lang['AdminMain.index.text_description_incoming'] = 'Menerima permintaan HTTP dan memicu peristiwa pada sistem menggunakan parameter yang diterima dalam permintaan. Permintaan dapat diterima dengan menggunakan GET, POST, atau JSON.';
$lang['AdminMain.index.text_description_outgoing'] = 'Mengirimkan permintaan HTTP ke URL ketika sebuah peristiwa dipicu. Permintaan dapat dikirim menggunakan GET, POST, atau JSON.';
$lang['AdminMain.index.option_delete'] = 'Menghapus';
$lang['AdminMain.index.option_edit'] = 'Sunting';
$lang['AdminMain.index.heading_options'] = 'Pilihan';
$lang['AdminMain.index.heading_method'] = 'Metode';
$lang['AdminMain.index.heading_event'] = 'Acara';
$lang['AdminMain.index.heading_callback'] = 'Panggilan balik';
$lang['AdminMain.index.boxtitle_webhooks'] = 'Kait web';
$lang['AdminMain.index.categorylink_addwebhook'] = 'Tambahkan Webhook';
$lang['AdminMain.index.category_outgoing'] = 'Keluar';
$lang['AdminMain.index.page_title_edit'] = 'Edit Webhook';
$lang['AdminMain.index.page_title_add'] = 'Tambahkan Webhook';
$lang['AdminMain.index.page_title_index'] = 'Kait web';
$lang['AdminMain.modal.delete_text'] = 'Apakah Anda yakin ingin menghapus webhook ini?';
$lang['AdminMain.!success.webhook_deleted'] = 'Webhook berhasil dihapus!';
$lang['AdminMain.!success.webhook_updated'] = 'Webhook berhasil diperbarui!';
$lang['AdminMain.!success.webhook_added'] = 'Webhook berhasil ditambahkan!';
$lang['AdminMain.!tooltip.callback'] = 'Callback merepresentasikan ke mana permintaan akan dikirim atau diterima, untuk webhook keluar harus berupa URL dan untuk webhook masuk harus berupa nama URL tempat permintaan akan diterima. contoh: http://blesta.com/plugin/webhooks/trigger/index/[Nama Callback].';

==> blesta-5.11.4.zip: blesta/plugins/webhooks/language/id_id/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.id_id
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.index.category_incoming'] = 'Masuk';
$lang['AdminMain.edit.text_fields_map'] = 'Bagian ini memungkinkan Anda mengganti nama bidang peristiwa yang dipicu menjadi nama khusus sebelum dikirim ke panggilan balik. Subbidang harus dipisahkan dengan titik (misalnya vars.status). Untuk melihat daftar semua bidang yang didukung oleh masing-masing peristiwa, Anda dapat memeriksa <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">tautan</a> berikut ini.';
$lang['AdminMain.edit.field_editsubmit'] = 'Edit Webhook';
$lang['AdminMain.edit.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminMain.edit.field_method'] = 'Metode';
$lang['AdminMain.edit.field_type'] = 'Panggilan balik';
$lang['AdminMain.edit.field_event'] = 'Acara';
$lang['AdminMain.edit.field_callback'] = 'Panggilan balik';
$lang['AdminMain.edit.option_delete'] = 'Menghapus';
$lang['AdminMain.edit.heading_options'] = 'Pilihan';
$lang['AdminMain.edit.heading_parameter'] = 'Bidang Baru';
$lang['AdminMain.edit.heading_field'] = 'Bidang Asli';
$lang['AdminMain.edit.heading_fields_map'] = 'Peta Bidang';
$lang['AdminMain.edit.heading_event'] = 'Acara';
$lang['AdminMain.edit.boxtitle_editwebhook'] = 'Edit Webhook';
$lang['AdminMain.add.text_fields_map'] = 'Bagian ini memungkinkan Anda mengganti nama bidang peristiwa yang dipicu menjadi nama khusus sebelum dikirim ke panggilan balik. Subbidang harus dipisahkan dengan titik (misalnya vars.status). Untuk melihat daftar semua bidang yang didukung oleh masing-masing peristiwa, Anda dapat memeriksa <a href="https://docs.blesta.com/display/dev/Event+Handlers" target="_blank">tautan</a> berikut ini.';
$lang['AdminMain.add.field_addsubmit'] = 'Tambahkan Webhook';
$lang['AdminMain.add.field_add_field'] = 'Tambahkan Bidang';
$lang['AdminMain.add.field_method'] = 'Metode';
$lang['AdminMain.add.field_type'] = 'Panggilan balik';
$lang['AdminMain.add.field_event'] = 'Acara';
$lang['AdminMain.add.field_callback'] = 'Panggilan balik';
$lang['AdminMain.add.option_delete'] = 'Menghapus';
$lang['AdminMain.add.heading_options'] = 'Pilihan';
$lang['AdminMain.add.heading_parameter'] = 'Bidang Baru';
$lang['AdminMain.add.heading_field'] = 'Bidang Asli';
$lang['AdminMain.add.heading_fields_map'] = 'Peta Bidang';
$lang['AdminMain.add.heading_event'] = 'Acara';
$lang['AdminMain.add.boxtitle_addwebhook'] = 'Tambahkan Webhook';
$lang['AdminMain.index.no_results'] = 'Tidak ada webhook yang tersedia.';
$lang['AdminMain.index.text_description_incoming'] = 'Menerima permintaan HTTP dan memicu peristiwa pada sistem menggunakan parameter yang diterima dalam permintaan. Permintaan dapat diterima dengan menggunakan GET, POST, atau JSON.';
$lang['AdminMain.index.text_description_outgoing'] = 'Mengirimkan permintaan HTTP ke URL ketika sebuah peristiwa dipicu. Permintaan dapat dikirim menggunakan GET, POST, PUT, atau JSON.';
$lang['AdminMain.index.option_delete'] = 'Menghapus';
$lang['AdminMain.index.option_edit'] = 'Sunting';
$lang['AdminMain.index.heading_options'] = 'Pilihan';
$lang['AdminMain.index.heading_method'] = 'Metode';
$lang['AdminMain.index.heading_event'] = 'Acara';
$lang['AdminMain.index.heading_callback'] = 'Panggilan balik';
$lang['AdminMain.index.boxtitle_webhooks'] = 'Kait web';
$lang['AdminMain.index.categorylink_addwebhook'] = 'Tambahkan Webhook';
$lang['AdminMain.index.category_outgoing'] = 'Keluar';
$lang['AdminMain.index.page_title_edit'] = 'Edit Webhook';
$lang['AdminMain.index.page_title_add'] = 'Tambahkan Webhook';
$lang['AdminMain.index.page_title_index'] = 'Kait web';
$lang['AdminMain.modal.delete_text'] = 'Apakah Anda yakin ingin menghapus webhook ini?';
$lang['AdminMain.!success.webhook_deleted'] = 'Webhook berhasil dihapus!';
$lang['AdminMain.!success.webhook_updated'] = 'Webhook berhasil diperbarui!';
$lang['AdminMain.!success.webhook_added'] = 'Webhook berhasil ditambahkan!';
$lang['AdminMain.!tooltip.callback'] = 'Callback merepresentasikan ke mana permintaan akan dikirim atau diterima, untuk webhook keluar harus berupa URL dan untuk webhook masuk harus berupa nama URL tempat permintaan akan diterima. contoh: http://blesta.com/plugin/webhooks/trigger/index/[Nama Callback].';
$lang['AdminMain.edit.field_cancel'] = 'Batal';
$lang['AdminMain.add.field_cancel'] = 'Batal';
